% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/7_impute.R
\name{normimpute}
\alias{normimpute}
\alias{halfnormimpute}
\alias{zeroimpute}
\alias{translate}
\title{Impute from half-normal distribution around 0}
\usage{
normimpute(x, selector = is.na(x), mean = 0)

halfnormimpute(x, selector = is.na(x))

zeroimpute(x, selector = is.na(x))

translate(
  x,
  ref = c(min, mean, median, max)[[1]],
  pos = 3 * sd(x, na.rm = TRUE)
)
}
\arguments{
\item{x}{NA-containing numeric vector}

\item{selector}{which values to impute}

\item{mean}{number}

\item{ref}{reference : which reference value away from which to impute}

\item{pos}{position  : how many sds away to impute}
}
\value{
numeric vector of same length
}
\description{
Impute from half-normal distribution around 0
}
\examples{
require(data.table)
x <- rnorm(1e5)
idx <- runif(length(x))>0.9
x[idx] <- NA
dt1 <- data.table(value = normimpute(x), distr = 'norm')

x <- abs(rnorm(1e5)); x[idx] <- NA
dt2 <- data.table(value = halfnormimpute(x), distr = 'halfnorm')

x <- abs(rnorm(1e5)); x[idx] <- NA
dt3 <- data.table(value = zeroimpute(x), distr = 'zero')

x <- abs(rnorm(1e5)); x[idx] <- NA
dt4 <- data.table(value = translate(x), distr = 'translate')

require(ggplot2)
ggplot(rbind(dt1,dt2,dt3, dt4), aes(x=value, fill=distr)) +
geom_density(alpha=0.5)
}
